@@ -38,20 +38,20 @@ extern PyObject *GitError;
 extern PyTypeObject BlobType;
 
 PyDoc_STRVAR(Blob_diff__doc__,
-  "diff([blob, flag, old_as_path, new_as_path] -> Patch\n"
+  "diff([blob, flag, old_as_path, new_as_path]) -> Patch\n"
   "\n"
   "Directly generate a :py:class:`pygit2.Patch` from the difference\n"
-  "  between two blobs.\n"
+  "between two blobs.\n"
   "\n"
-  "Arguments:\n"
+  ":param Blob blob: the :py:class:`~pygit2.Blob` to diff.\n"
   "\n"
-  "blob: the :py:class:`~pygit2.Blob` to diff.\n"
+  ":param flag: a GIT_DIFF_* constant.\n"
   "\n"
-  "flag: a GIT_DIFF_* constant.\n"
+  ":param str old_as_path: treat old blob as if it had this filename.\n"
   "\n"
-  "old_as_path: treat old blob as if it had this filename.\n"
+  ":param str new_as_path: treat new blob as if it had this filename.\n"
   "\n"
-  "new_as_path: treat new blob as if it had this filename.\n");
+  ":rtype: Patch\n");
 
 PyObject *
 Blob_diff(Blob *self, PyObject *args, PyObject *kwds)
@@ -63,7 +63,7 @@ Blob_diff(Blob *self, PyObject *args, PyObject *kwds)
     int err;
     char *keywords[] = {"blob", "flag", "old_as_path", "new_as_path", NULL};
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, "|O!ssI", keywords,
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "|O!Iss", keywords,
                                      &BlobType, &py_blob, &opts.flags,
                                      &old_as_path, &new_as_path))
         return NULL;
@@ -79,20 +79,20 @@ Blob_diff(Blob *self, PyObject *args, PyObject *kwds)
 
 
 PyDoc_STRVAR(Blob_diff_to_buffer__doc__,
-  "diff_to_buffer([buffer, flag, old_as_path, buffer_as_path] -> Patch\n"
+  "diff_to_buffer([buffer, flag, old_as_path, buffer_as_path]) -> Patch\n"
   "\n"
   "Directly generate a :py:class:`~pygit2.Patch` from the difference\n"
-  "  between a blob and a buffer.\n"
+  "between a blob and a buffer.\n"
   "\n"
-  "Arguments:\n"
+  ":param Blob buffer: Raw data for new side of diff.\n"
   "\n"
-  "buffer: Raw data for new side of diff.\n"
+  ":param flag: a GIT_DIFF_* constant.\n"
   "\n"
-  "flag: a GIT_DIFF_* constant.\n"
+  ":param str old_as_path: treat old blob as if it had this filename.\n"
   "\n"
-  "old_as_path: treat old blob as if it had this filename.\n"
+  ":param str buffer_as_path: treat buffer as if it had this filename.\n"
   "\n"
-  "buffer_as_path: treat buffer as if it had this filename.\n");
+  ":rtype: Patch\n");
 
 PyObject *
 Blob_diff_to_buffer(Blob *self, PyObject *args, PyObject *kwds)
@@ -106,7 +106,7 @@ Blob_diff_to_buffer(Blob *self, PyObject *args, PyObject *kwds)
     char *keywords[] = {"buffer", "flag", "old_as_path", "buffer_as_path",
                         NULL};
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, "|s#ssI", keywords,
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "|s#Iss", keywords,
                                      &buffer, &buffer_len, &opts.flags,
                                      &old_as_path, &buffer_as_path))
         return NULL;
@@ -158,8 +158,58 @@ PyGetSetDef Blob_getseters[] = {
     {NULL}
 };
 
+static int
+Blob_getbuffer(Blob *self, Py_buffer *view, int flags)
+{
+    return PyBuffer_FillInfo(view, (PyObject *) self,
+                             (void *) git_blob_rawcontent(self->blob),
+                             git_blob_rawsize(self->blob), 1, flags);
+}
 
-PyDoc_STRVAR(Blob__doc__, "Blob objects.");
+#if PY_MAJOR_VERSION == 2
+
+static Py_ssize_t
+Blob_getreadbuffer(Blob *self, Py_ssize_t index, const void **ptr)
+{
+    if (index != 0) {
+        PyErr_SetString(PyExc_SystemError,
+                        "accessing non-existent blob segment");
+        return -1;
+    }
+    *ptr = (void *) git_blob_rawcontent(self->blob);
+    return git_blob_rawsize(self->blob);
+}
+
+static Py_ssize_t
+Blob_getsegcount(Blob *self, Py_ssize_t *lenp)
+{
+    if (lenp)
+        *lenp = git_blob_rawsize(self->blob);
+
+    return 1;
+}
+
+static PyBufferProcs Blob_as_buffer = {
+    (readbufferproc)Blob_getreadbuffer,
+    NULL,                       /* bf_getwritebuffer */
+    (segcountproc)Blob_getsegcount,
+    NULL,                       /* charbufferproc */
+    (getbufferproc)Blob_getbuffer,
+};
+
+#else
+
+static PyBufferProcs Blob_as_buffer = {
+    (getbufferproc)Blob_getbuffer,
+};
+
+#endif  /* python 2 vs python 3 buffers */
+
+PyDoc_STRVAR(Blob__doc__, "Blob object.\n"
+  "\n"
+  "Blobs implement the buffer interface, which means you can get access\n"
+  "to its data via `memoryview(blob)` without the need to create a copy."
+);
 
 PyTypeObject BlobType = {
     PyVarObject_HEAD_INIT(NULL, 0)
@@ -180,8 +230,14 @@ PyTypeObject BlobType = {
     0,                                         /* tp_str            */
     0,                                         /* tp_getattro       */
     0,                                         /* tp_setattro       */
-    0,                                         /* tp_as_buffer      */
+    &Blob_as_buffer,                           /* tp_as_buffer      */
+#if PY_MAJOR_VERSION == 2
+    Py_TPFLAGS_DEFAULT |                       /* tp_flags          */
+    Py_TPFLAGS_HAVE_GETCHARBUFFER |
+    Py_TPFLAGS_HAVE_NEWBUFFER,
+#else
     Py_TPFLAGS_DEFAULT,                        /* tp_flags          */
+#endif
     Blob__doc__,                               /* tp_doc            */
     0,                                         /* tp_traverse       */
     0,                                         /* tp_clear          */
