@@ -40,8 +40,6 @@ from os.path import join, realpath
 
 # Import from pygit2
 from pygit2 import GIT_OBJ_ANY, GIT_OBJ_BLOB, GIT_OBJ_COMMIT
-from pygit2 import GIT_MERGE_ANALYSIS_NONE, GIT_MERGE_ANALYSIS_NORMAL, GIT_MERGE_ANALYSIS_UP_TO_DATE
-from pygit2 import GIT_MERGE_ANALYSIS_FASTFORWARD, GIT_MERGE_ANALYSIS_UNBORN
 from pygit2 import init_repository, clone_repository, clone_into, discover_repository
 from pygit2 import Oid, Reference, hashfile
 import pygit2
@@ -215,7 +213,7 @@ class RepositoryTest_II(utils.RepoTestCase):
         head = self.repo.head
         head = self.repo[head.target]
         self.assertTrue('new' not in head.tree)
-        self.repo.checkout(ref_i18n, pygit2.GIT_CHECKOUT_FORCE)
+        self.repo.checkout(ref_i18n, strategy=pygit2.GIT_CHECKOUT_FORCE)
 
         head = self.repo.head
         head = self.repo[head.target]
@@ -245,9 +243,17 @@ class RepositoryTest_II(utils.RepoTestCase):
         self.assertTrue('bye.txt' in self.repo.status())
 
         # checkout from head will reset index as well
-        self.repo.checkout('HEAD', pygit2.GIT_CHECKOUT_FORCE)
+        self.repo.checkout('HEAD', strategy=pygit2.GIT_CHECKOUT_FORCE)
         self.assertTrue('bye.txt' not in self.repo.status())
 
+    def test_checkout_alternative_dir(self):
+        ref_i18n = self.repo.lookup_reference('refs/heads/i18n')
+        extra_dir = os.path.join(self.repo.workdir, 'extra-dir')
+        os.mkdir(extra_dir)
+        self.assertTrue(len(os.listdir(extra_dir)) == 0)
+        self.repo.checkout(ref_i18n, directory=extra_dir)
+        self.assertFalse(len(os.listdir(extra_dir)) == 0)
+
     def test_merge_base(self):
         commit = self.repo.merge_base(
             '5ebeeebb320790caf276b9fc8b24546d63316533',
@@ -318,69 +324,6 @@ class RepositoryTest_II(utils.RepoTestCase):
         self.assertTrue("hola mundo\n" in diff.patch)
         self.assertTrue("bonjour le monde\n" in diff.patch)
 
-
-class RepositoryTest_III(utils.RepoTestCaseForMerging):
-
-    def test_merge_none(self):
-        self.assertRaises(TypeError, self.repo.merge, None)
-
-    def test_merge_analysis_uptodate(self):
-        branch_head_hex = '5ebeeebb320790caf276b9fc8b24546d63316533'
-        branch_id = self.repo.get(branch_head_hex).id
-        analysis, preference = self.repo.merge_analysis(branch_id)
-
-        self.assertTrue(analysis & GIT_MERGE_ANALYSIS_UP_TO_DATE)
-        self.assertFalse(analysis & GIT_MERGE_ANALYSIS_FASTFORWARD)
-        self.assertEqual({}, self.repo.status())
-
-    def test_merge_analysis_fastforward(self):
-        branch_head_hex = 'e97b4cfd5db0fb4ebabf4f203979ca4e5d1c7c87'
-        branch_id = self.repo.get(branch_head_hex).id
-        analysis, preference = self.repo.merge_analysis(branch_id)
-        self.assertFalse(analysis & GIT_MERGE_ANALYSIS_UP_TO_DATE)
-        self.assertTrue(analysis & GIT_MERGE_ANALYSIS_FASTFORWARD)
-        self.assertEqual({}, self.repo.status())
-
-    def test_merge_no_fastforward_no_conflicts(self):
-        branch_head_hex = '03490f16b15a09913edb3a067a3dc67fbb8d41f1'
-        branch_id = self.repo.get(branch_head_hex).id
-        analysis, preference = self.repo.merge_analysis(branch_id)
-        self.assertFalse(analysis & GIT_MERGE_ANALYSIS_UP_TO_DATE)
-        self.assertFalse(analysis & GIT_MERGE_ANALYSIS_FASTFORWARD)
-        # Asking twice to assure the reference counting is correct
-        self.assertEqual({}, self.repo.status())
-        self.assertEqual({}, self.repo.status())
-
-    def test_merge_no_fastforward_conflicts(self):
-        branch_head_hex = '1b2bae55ac95a4be3f8983b86cd579226d0eb247'
-        branch_id = self.repo.get(branch_head_hex).id
-
-        analysis, preference = self.repo.merge_analysis(branch_id)
-        self.assertFalse(analysis & GIT_MERGE_ANALYSIS_UP_TO_DATE)
-        self.assertFalse(analysis & GIT_MERGE_ANALYSIS_FASTFORWARD)
-
-        self.repo.merge(branch_id)
-        status = pygit2.GIT_STATUS_WT_NEW | pygit2.GIT_STATUS_INDEX_DELETED
-        # Asking twice to assure the reference counting is correct
-        self.assertEqual({'.gitignore': status}, self.repo.status())
-        self.assertEqual({'.gitignore': status}, self.repo.status())
-        # Checking the index works as expected
-        self.repo.index.add('.gitignore')
-        self.repo.index.write()
-        self.assertEqual({'.gitignore': pygit2.GIT_STATUS_INDEX_MODIFIED}, self.repo.status())
-
-    def test_merge_invalid_hex(self):
-        branch_head_hex = '12345678'
-        self.assertRaises(KeyError, self.repo.merge, branch_head_hex)
-
-    def test_merge_already_something_in_index(self):
-        branch_head_hex = '03490f16b15a09913edb3a067a3dc67fbb8d41f1'
-        branch_oid = self.repo.get(branch_head_hex).id
-        with open(os.path.join(self.repo.workdir, 'inindex.txt'), 'w') as f:
-            f.write('new content')
-        self.repo.index.add('inindex.txt')
-        self.assertRaises(pygit2.GitError, self.repo.merge, branch_oid)
-
 class RepositorySignatureTest(utils.RepoTestCase):
 
     def test_default_signature(self):
